obs_source_audio_output_capture_device_changed

Function obs_source_audio_output_capture_device_changed 

pub unsafe extern "C" fn obs_source_audio_output_capture_device_changed(
    source: *mut obs_source_t,
    device_id: *const c_char,
)
For an Audio Output Capture source (like ‘wasapi_output_capture’) used for ‘Desktop Audio’, this checks whether the device is also used for monitoring. A signal to obs core struct is then emitted to trigger deduplication logic at the end of an audio tick.